==> vtk-6.3.0-5-armv6h.pkg.tar.xz: vtk/vtkImageImport.java <==
// java wrapper for vtkImageImport object
//

package vtk;
import vtk.*;

public class vtkImageImport extends vtkImageAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetDataScalarType_2(int id0);
  public void SetDataScalarType(int id0)
    { SetDataScalarType_2(id0); }

  private native void SetDataScalarTypeToDouble_3();
  public void SetDataScalarTypeToDouble()
    { SetDataScalarTypeToDouble_3(); }

  private native void SetDataScalarTypeToFloat_4();
  public void SetDataScalarTypeToFloat()
    { SetDataScalarTypeToFloat_4(); }

  private native void SetDataScalarTypeToInt_5();
  public void SetDataScalarTypeToInt()
    { SetDataScalarTypeToInt_5(); }

  private native void SetDataScalarTypeToShort_6();
  public void SetDataScalarTypeToShort()
    { SetDataScalarTypeToShort_6(); }

  private native void SetDataScalarTypeToUnsignedShort_7();
  public void SetDataScalarTypeToUnsignedShort()
    { SetDataScalarTypeToUnsignedShort_7(); }

  private native void SetDataScalarTypeToUnsignedChar_8();
  public void SetDataScalarTypeToUnsignedChar()
    { SetDataScalarTypeToUnsignedChar_8(); }

  private native int GetDataScalarType_9();
  public int GetDataScalarType()
    { return GetDataScalarType_9(); }

  private native String GetDataScalarTypeAsString_10();
  public String GetDataScalarTypeAsString()
    { return GetDataScalarTypeAsString_10(); }

  private native void SetNumberOfScalarComponents_11(int id0);
  public void SetNumberOfScalarComponents(int id0)
    { SetNumberOfScalarComponents_11(id0); }

  private native int GetNumberOfScalarComponents_12();
  public int GetNumberOfScalarComponents()
    { return GetNumberOfScalarComponents_12(); }

  private native void SetDataExtent_13(int id0,int id1,int id2,int id3,int id4,int id5);
  public void SetDataExtent(int id0,int id1,int id2,int id3,int id4,int id5)
    { SetDataExtent_13(id0,id1,id2,id3,id4,id5); }

  private native void SetDataExtent_14(int id0[]);
  public void SetDataExtent(int id0[])
    { SetDataExtent_14(id0); }

  private native int[]  GetDataExtent_15();
  public int[]  GetDataExtent()
    { return GetDataExtent_15(); }

  private native void SetDataExtentToWholeExtent_16();
  public void SetDataExtentToWholeExtent()
    { SetDataExtentToWholeExtent_16(); }

  private native void SetDataSpacing_17(double id0,double id1,double id2);
  public void SetDataSpacing(double id0,double id1,double id2)
    { SetDataSpacing_17(id0,id1,id2); }

  private native void SetDataSpacing_18(double id0[]);
  public void SetDataSpacing(double id0[])
    { SetDataSpacing_18(id0); }

  private native double[] GetDataSpacing_19();
  public double[] GetDataSpacing()
    { return GetDataSpacing_19(); }

  private native void SetDataOrigin_20(double id0,double id1,double id2);
  public void SetDataOrigin(double id0,double id1,double id2)
    { SetDataOrigin_20(id0,id1,id2); }

  private native void SetDataOrigin_21(double id0[]);
  public void SetDataOrigin(double id0[])
    { SetDataOrigin_21(id0); }

  private native double[] GetDataOrigin_22();
  public double[] GetDataOrigin()
    { return GetDataOrigin_22(); }

  private native void SetWholeExtent_23(int id0,int id1,int id2,int id3,int id4,int id5);
  public void SetWholeExtent(int id0,int id1,int id2,int id3,int id4,int id5)
    { SetWholeExtent_23(id0,id1,id2,id3,id4,id5); }

  private native void SetWholeExtent_24(int id0[]);
  public void SetWholeExtent(int id0[])
    { SetWholeExtent_24(id0); }

  private native int[]  GetWholeExtent_25();
  public int[]  GetWholeExtent()
    { return GetWholeExtent_25(); }

  private native void SetScalarArrayName_26(String id0);
  public void SetScalarArrayName(String id0)
    { SetScalarArrayName_26(id0); }

  private native String GetScalarArrayName_27();
  public String GetScalarArrayName()
    { return GetScalarArrayName_27(); }

  private native int InvokePipelineModifiedCallbacks_28();
  public int InvokePipelineModifiedCallbacks()
    { return InvokePipelineModifiedCallbacks_28(); }

  private native void InvokeUpdateInformationCallbacks_29();
  public void InvokeUpdateInformationCallbacks()
    { InvokeUpdateInformationCallbacks_29(); }

  private native void InvokeExecuteInformationCallbacks_30();
  public void InvokeExecuteInformationCallbacks()
    { InvokeExecuteInformationCallbacks_30(); }

  private native void InvokeExecuteDataCallbacks_31();
  public void InvokeExecuteDataCallbacks()
    { InvokeExecuteDataCallbacks_31(); }

  private native void LegacyCheckWholeExtent_32();
  public void LegacyCheckWholeExtent()
    { LegacyCheckWholeExtent_32(); }

  public vtkImageImport() { super(); }

  public vtkImageImport(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-13-armv6h.pkg.tar.xz: vtk/vtkImageImport.java <==
// java wrapper for vtkImageImport object
//

package vtk;
import vtk.*;

public class vtkImageImport extends vtkImageAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetDataScalarType_2(int id0);
  public void SetDataScalarType(int id0)
    { SetDataScalarType_2(id0); }

  private native void SetDataScalarTypeToDouble_3();
  public void SetDataScalarTypeToDouble()
    { SetDataScalarTypeToDouble_3(); }

  private native void SetDataScalarTypeToFloat_4();
  public void SetDataScalarTypeToFloat()
    { SetDataScalarTypeToFloat_4(); }

  private native void SetDataScalarTypeToInt_5();
  public void SetDataScalarTypeToInt()
    { SetDataScalarTypeToInt_5(); }

  private native void SetDataScalarTypeToShort_6();
  public void SetDataScalarTypeToShort()
    { SetDataScalarTypeToShort_6(); }

  private native void SetDataScalarTypeToUnsignedShort_7();
  public void SetDataScalarTypeToUnsignedShort()
    { SetDataScalarTypeToUnsignedShort_7(); }

  private native void SetDataScalarTypeToUnsignedChar_8();
  public void SetDataScalarTypeToUnsignedChar()
    { SetDataScalarTypeToUnsignedChar_8(); }

  private native int GetDataScalarType_9();
  public int GetDataScalarType()
    { return GetDataScalarType_9(); }

  private native String GetDataScalarTypeAsString_10();
  public String GetDataScalarTypeAsString()
    { return GetDataScalarTypeAsString_10(); }

  private native void SetNumberOfScalarComponents_11(int id0);
  public void SetNumberOfScalarComponents(int id0)
    { SetNumberOfScalarComponents_11(id0); }

  private native int GetNumberOfScalarComponents_12();
  public int GetNumberOfScalarComponents()
    { return GetNumberOfScalarComponents_12(); }

  private native void SetDataExtent_13(int id0,int id1,int id2,int id3,int id4,int id5);
  public void SetDataExtent(int id0,int id1,int id2,int id3,int id4,int id5)
    { SetDataExtent_13(id0,id1,id2,id3,id4,id5); }

  private native void SetDataExtent_14(int id0[]);
  public void SetDataExtent(int id0[])
    { SetDataExtent_14(id0); }

  private native int[]  GetDataExtent_15();
  public int[]  GetDataExtent()
    { return GetDataExtent_15(); }

  private native void SetDataExtentToWholeExtent_16();
  public void SetDataExtentToWholeExtent()
    { SetDataExtentToWholeExtent_16(); }

  private native void SetDataSpacing_17(double id0,double id1,double id2);
  public void SetDataSpacing(double id0,double id1,double id2)
    { SetDataSpacing_17(id0,id1,id2); }

  private native void SetDataSpacing_18(double id0[]);
  public void SetDataSpacing(double id0[])
    { SetDataSpacing_18(id0); }

  private native double[] GetDataSpacing_19();
  public double[] GetDataSpacing()
    { return GetDataSpacing_19(); }

  private native void SetDataOrigin_20(double id0,double id1,double id2);
  public void SetDataOrigin(double id0,double id1,double id2)
    { SetDataOrigin_20(id0,id1,id2); }

  private native void SetDataOrigin_21(double id0[]);
  public void SetDataOrigin(double id0[])
    { SetDataOrigin_21(id0); }

  private native double[] GetDataOrigin_22();
  public double[] GetDataOrigin()
    { return GetDataOrigin_22(); }

  private native void SetWholeExtent_23(int id0,int id1,int id2,int id3,int id4,int id5);
  public void SetWholeExtent(int id0,int id1,int id2,int id3,int id4,int id5)
    { SetWholeExtent_23(id0,id1,id2,id3,id4,id5); }

  private native void SetWholeExtent_24(int id0[]);
  public void SetWholeExtent(int id0[])
    { SetWholeExtent_24(id0); }

  private native int[]  GetWholeExtent_25();
  public int[]  GetWholeExtent()
    { return GetWholeExtent_25(); }

  private native void SetScalarArrayName_26(String id0);
  public void SetScalarArrayName(String id0)
    { SetScalarArrayName_26(id0); }

  private native String GetScalarArrayName_27();
  public String GetScalarArrayName()
    { return GetScalarArrayName_27(); }

  private native int InvokePipelineModifiedCallbacks_28();
  public int InvokePipelineModifiedCallbacks()
    { return InvokePipelineModifiedCallbacks_28(); }

  private native void InvokeUpdateInformationCallbacks_29();
  public void InvokeUpdateInformationCallbacks()
    { InvokeUpdateInformationCallbacks_29(); }

  private native void InvokeExecuteInformationCallbacks_30();
  public void InvokeExecuteInformationCallbacks()
    { InvokeExecuteInformationCallbacks_30(); }

  private native void InvokeExecuteDataCallbacks_31();
  public void InvokeExecuteDataCallbacks()
    { InvokeExecuteDataCallbacks_31(); }

  private native void LegacyCheckWholeExtent_32();
  public void LegacyCheckWholeExtent()
    { LegacyCheckWholeExtent_32(); }

  public vtkImageImport() { super(); }

  public vtkImageImport(long id) { super(id); }
  public native long   VTKInit();

}
